stdpairs: Symbolic computation over a monomial ideal of an affine (non-normal) semigroup ring
=============================================================================================

Description
-----------

Sage library for doing symbolic computation over a monomial ideal of an affine (non-normal) semigroup ring.

License
-------

GPLv3

Upstream Contact
----------------

https://pypi.org/project/stdpairs/
